pyxmpp.jabber.disco.DiscoItem

Package pyxmpp :: Package jabber :: Module disco :: Class DiscoItem |
[hide private]

# Class DiscoItem

source code

                            object --+
                                     |
    objects.StanzaPayloadWrapperObject --+
                                         |
                                        DiscoItem

An item of disco#items reply.

Instance Methods | [hide private]
__init__(self, disco, xmlnode_or_jid, node=None, name=None, action=None) Initialize an DiscoItem object. | source code
__del__(self) | source code
__str__(self) str(x) | source code
remove(self) Remove `self` from the containing DiscoItems object. | source code
`unicode` |
get_name(self) Get the name of the item. | source code
set_name(self, name) Set the name of the item. | source code
`unicode` |
get_node(self) Get the node of the item. | source code
set_node(self, node) Set the node of the item. | source code
`unicode` |
get_action(self) Get the action attribute of the item. | source code
set_action(self, action) Set the action of the item. | source code
JID |
get_jid(self) Get the JID of the item. | source code
set_jid(self, jid) Set the JID of the item. | source code
Inherited from `objects.StanzaPayloadWrapperObject`: `as_xml` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Instance Variables | [hide private]
`unicode` | name name of the item.
`unicode` | node node name of the item.
`unicode` | action action of the item.
JID | jid the JID of the item.
DiscoItems | disco the disco reply this is the part of.
`libxml2.xmlNode` | xmlnode XML node of the object.

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, disco, xmlnode_or_jid, node=None, name=None, action=None) (Constructor) | source code
Initialize an DiscoItem object. Parameters: `disco` (DiscoItems) - the disco#items reply `self` is a part of. `xmlnode_or_jid` (`libxml2.xmlNode` or JID) - XML element describing the item or the JID of the item. `node` (`unicode`) - disco node of the item. `name` (`unicode`) - name of the item. `action` (`unicode`) - 'action' attribute of the item. Overrides: object.__init__

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)

### get_name(self) | source code
Get the name of the item. Returns: `unicode` the name of the item or `None`.

### set_name(self, name) | source code
Set the name of the item. Parameters: `name` (`unicode`) - the new name or `None`.

### get_node(self) | source code
Get the node of the item. Returns: `unicode` the node of the item or `None`.

### set_node(self, node) | source code
Set the node of the item. Parameters: `node` (`unicode`) - the new node or `None`.

### get_action(self) | source code
Get the action attribute of the item. Returns: `unicode` the action of the item or `None`.

### set_action(self, action) | source code
Set the action of the item. Parameters: `action` (`unicode`) - the new action or `None`.

### get_jid(self) | source code
Get the JID of the item. Returns: JID the JID of the item.

### set_jid(self, jid) | source code
Set the JID of the item. Parameters: `jid` (JID) - the new jid.

Instance Variable Details | [hide private]

### name name of the item. Get Method: get_name(self) - Get the name of the item. Set Method: set_name(self, name) - Set the name of the item. Type: `unicode`

### node node name of the item. Get Method: get_node(self) - Get the node of the item. Set Method: set_node(self, node) - Set the node of the item. Type: `unicode`

### action action of the item. Get Method: get_action(self) - Get the action attribute of the item. Set Method: set_action(self, action) - Set the action of the item. Type: `unicode`

### jid the JID of the item. Get Method: get_jid(self) - Get the JID of the item. Set Method: set_jid(self, jid) - Set the JID of the item. Type: JID